@@ -1,21 +1,9 @@
-/***************************************************************************
- *   Copyright 2009 Stefan Majewsky <majewsky@gmx.net>
- *   Copyright 2014 Ian Wadham <iandw.au@gmail.com>
- *
- *   This program is free software; you can redistribute it and/or
- *   modify it under the terms of the GNU General Public
- *   License as published by the Free Software Foundation; either
- *   version 2 of the License, or (at your option) any later version.
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details.
- *
- *   You should have received a copy of the GNU General Public License
- *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2009 Stefan Majewsky <majewsky@gmx.net>
+    SPDX-FileCopyrightText: 2014 Ian Wadham <iandw.au@gmail.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #ifndef PALAPELI_GAMEPLAY_H
 #define PALAPELI_GAMEPLAY_H
@@ -52,8 +40,8 @@ namespace Palapeli
 	{
 		Q_OBJECT
 		public:
-			explicit GamePlay(MainWindow* mainWindow = 0);
-			virtual ~GamePlay();
+			explicit GamePlay(MainWindow* mainWindow = nullptr);
+			~GamePlay() override;
 			void    init();
 			void    shutdown();
 			CollectionView* collectionView()
